@@ -1,10 +1,10 @@
 from typing import TYPE_CHECKING
-import warnings
+
 from aiohttp_sqlalchemy.constants import DEFAULT_KEY
 from aiohttp_sqlalchemy.decorators import sa_decorator
-from aiohttp_sqlalchemy.exceptions import DuplicateAppKeyError
+from aiohttp_sqlalchemy.exceptions import DuplicateAppKeyError, DuplicateRequestKeyError
 from aiohttp_sqlalchemy.middlewares import sa_middleware
-from aiohttp_sqlalchemy.views import SAView, SAViewMixin
+from aiohttp_sqlalchemy.views import SABaseView, SAView, SAViewMixin
 
 
 if TYPE_CHECKING:
@@ -15,7 +15,11 @@ if TYPE_CHECKING:
     TSABinding = Tuple[AsyncEngine, str, bool]
 
 
-__version__ = '0.4.0'
+__version__ = '0.5.0'
+
+__all__ = ['DuplicateAppKeyError', 'DuplicateRequestKeyError', 'SABaseView',
+           'sa_bind', 'sa_decorator', 'sa_middleware', 'SAView',
+           'SAViewMixin', 'setup',]
 
 
 def sa_bind(engine: 'AsyncEngine', key: str = DEFAULT_KEY, *,
@@ -24,14 +28,6 @@ def sa_bind(engine: 'AsyncEngine', key: str = DEFAULT_KEY, *,
     return engine, key, middleware
 
 
-def sa_engine(engine: 'AsyncEngine', key: str = DEFAULT_KEY, *,
-              middleware: bool = True) -> 'TSABinding':
-    msg = "aiohttp_sqlalchemy.sa_engine() is deprecated. " \
-          "Use aiohttp_sqlalchemy.sa_bind()."
-    warnings.warn(msg, DeprecationWarning, stacklevel=2)
-    return engine, key, middleware
-
-
 def setup(app: 'Application', bindings: 'Iterable[TSABinding]'):
     """ Setup function for binding SQLAlchemy engines. """
     for engine, key, middleware in bindings:
